/*
 * UNIX SMBlib NetBIOS implementation
 * 
 * Version 1.0
 * SMBlib Utility routines for changing parts of structures so I can test
 * SMB servers. These routines can do nasty things and should not be 
 * available.
 * 
 * Copyright (C) Richard Sharpe 1996
 * 
 */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <malloc.h>
#include <string.h>

#include <rfcnb.h>
#include <smblib.h>

void SMB_ProcessError (const char *fmt, ...)
{
  FILE *file = stderr;
  char buf[512];
  int  err = SMB_Get_Last_Error();

  if (fmt)
  {
    va_list args;
    va_start (args, fmt);
    vfprintf (file, fmt, args);
    va_end (args);
  }

  if (err == SMBlibE_Remote)  /* a remote host error */
  {
    err = SMB_Get_Last_SMB_Err();
    SMB_Get_SMB_Error_Msg (SMBlib_Error_Class (err),
                           SMBlib_Error_Code (err),
                           buf, sizeof(buf)-1);
  }
  else
    SMB_Get_Error_Msg (err, buf, sizeof(buf)-1);

  fprintf (file, "  %s\n", buf);
}

/*
 * Set the tid to what we want. We truncate to 0xFFFF
 */
void SMB_Set_Tree_TID (struct SMB_Tree *tree, int new_tid)
{
  if (new_tid < 0 || new_tid > 0x0000FFFF)
       tree->tid = 0x0000FFFF;
  else tree->tid = new_tid;
}

int SMB_Get_Tree_TID (struct SMB_Tree *tree)
{
  if (tree)
     return (tree->tid);
  return (0xFFFF);
}

/*
 * Set the connection to a new one in the tree.
 */
void SMB_Set_Tree_Con (struct SMB_Tree *tree, struct SMB_Connect *con)
{
  tree->con = con;
}

/*
 * Create a tree handle
 */
struct SMB_Tree *SMB_Create_Tree_Handle (struct SMB_Connect *con)
{
  struct SMB_Tree *tree = malloc (sizeof(*tree));

  if (!tree)
     return (NULL);
  tree->con = con;
  return (tree);
}
